#!/usr/bin/env bash

DEBUG=${DEBUG:=false}

source /hooks/common/functions

if [[ $1 == "--config" ]] ; then
  cat <<EOF
configVersion: v1
kubernetes:
- apiVersion: kustomize.toolkit.fluxcd.io/v1
  kind: Kustomization
  executeHookOnEvent: ["Added", "Modified", "Deleted"]
EOF
else
  [ $DEBUG = true ] && cp $BINDING_CONTEXT_PATH /tmp/
  # [ $DEBUG = true ] && echo "BINDING_CONTEXT_PATH $BINDING_CONTEXT_PATH"
  [ $DEBUG = true ] && echo "BINDING_CONTEXT_PATH : /tmp/$(basename $BINDING_CONTEXT_PATH)"
  type=$(jq -r .[0].type $BINDING_CONTEXT_PATH)

  case $type in
    Synchronization)
      for obj in $(jq -r '.[].objects[].object.metadata | "\(.namespace)/\(.name)"' $BINDING_CONTEXT_PATH);
      do
        argo::add::app ${obj} ks
      done
      garbage::collection ks
      ;;
    Event)
      for i in $(seq 0 $(jq -r '. | length - 1' $BINDING_CONTEXT_PATH))
      do
        watchEvent=$(jq -r ".[$i].watchEvent" $BINDING_CONTEXT_PATH)
        case $watchEvent in
          Added|Modified)
            echo "Added|Modified"
            for obj in $(jq -r ".[$i].object.metadata | \"\(.namespace)/\(.name)\"" $BINDING_CONTEXT_PATH);
            do
              argo::add::app ${obj} ks
            done
            ;;
          Deleted)
            echo "Deleted"
            for obj in $(jq -r ".[$i].object.metadata | \"\(.namespace)/\(.name)\"" $BINDING_CONTEXT_PATH);
            do
              argo::del::app ${obj} ks
            done
            ;;
          *)
            [ $DEBUG = true ] && echo "This Event type **${watchEvent}** is not supported"
            ;;
        esac
      done
      ;;
    *)
      [ $DEBUG = true ] && echo "Nothing to be done for $type"
      ;;
  esac
  exit 0
fi
